@@ -25,6 +25,7 @@
 #include "ct_text_view.h"
 #include "ct_actions.h"
 #include "ct_list.h"
+#include "ct_clipboard.h"
 
 std::unordered_map<std::string, GspellChecker*> CtTextView::_static_spell_checkers;
 
@@ -50,6 +51,7 @@ CtTextView::CtTextView(CtMainWin* pCtMainWin)
     {
         set_border_window_size(textWinType, 1);
     }
+
     // column edit signals
     signal_event_after().connect([&](GdkEvent* pEvent){
         switch (pEvent->type) {
@@ -82,22 +84,23 @@ CtTextView::CtTextView(CtMainWin* pCtMainWin)
 
 void CtTextView::setup_for_syntax(const std::string& syntax)
 {
+    _syntaxHighlighting = syntax;
 #ifdef MD_AUTO_REPLACEMENT
-    if (_markdown_filter_active()) _md_handler->active(syntax == CtConst::RICH_TEXT_ID);
+    if (_markdown_filter_active()) _md_handler->active(_syntaxHighlighting == CtConst::RICH_TEXT_ID);
 #endif // MD_AUTO_REPLACEMENT
 
     std::string new_class;
-    if (CtConst::RICH_TEXT_ID == syntax)         { new_class = "ct-view-rich-text"; }
-    else if (CtConst::PLAIN_TEXT_ID == syntax)   { new_class = "ct-view-plain-text"; }
-    else                                         { new_class = "ct-view-code"; }
+    if (CtConst::RICH_TEXT_ID == _syntaxHighlighting)       { new_class = "ct-view-rich-text"; }
+    else if (CtConst::PLAIN_TEXT_ID == _syntaxHighlighting) { new_class = "ct-view-plain-text"; }
+    else                                                    { new_class = "ct-view-code"; }
 
     if (new_class != "ct-view-rich-text") get_style_context()->remove_class("ct-view-rich-text");
     if (new_class != "ct-view-plain-text") get_style_context()->remove_class("ct-view-plain-text");
     if (new_class != "ct-view-code") get_style_context()->remove_class("ct-view-code");
     get_style_context()->add_class(new_class);
 
-    if ( CtConst::RICH_TEXT_ID == syntax or
-         CtConst::TABLE_CELL_TEXT_ID == syntax )
+    if ( CtConst::RICH_TEXT_ID == _syntaxHighlighting or
+         CtConst::TABLE_CELL_TEXT_ID == _syntaxHighlighting )
     {
         set_highlight_current_line(_pCtMainWin->get_ct_config()->rtHighlCurrLine);
         if (_pCtMainWin->get_ct_config()->rtShowWhiteSpaces) {
@@ -851,3 +854,25 @@ void CtTextView::_special_char_replace(Glib::ustring special_char, Gtk::TextIter
     _static_spell_checkers[lang] = gspell_checker;
     return gspell_checker;
 }
+
+void CtTextView::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
+                                       int x,
+                                       int y,
+                                       const Gtk::SelectionData& selection_data,
+                                       guint /*info*/,
+                                       guint time)
+{
+    bool success{false};
+    spdlog::debug("targets: {}", str::join(context->list_targets(), ", "));
+    if (vec::exists(context->list_targets(), CtConst::TARGET_URI_LIST)) {
+        int xb, yb;
+        window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, x, y, xb, yb);
+        Gtk::TextIter text_iter;
+        int trailing;
+        get_iter_at_position(text_iter, trailing, xb, yb); // works better than get_iter_at_location though has an issue
+        get_buffer()->place_cursor(text_iter);
+        CtClipboard{_pCtMainWin}.on_received_to_uri_list(selection_data, this, false/*forcePlain*/, true/*fromDragNDrop*/);
+        success = true;
+    }
+    context->drag_finish(success, false/*del*/, time);
+}
