@@ -72,6 +72,7 @@ public:
         return _columnEdit.own_insert_delete_active();
     }
     guint64 get_todo_rotate_time() { return _todoRotateTime; }
+    std::string get_syntax_highlighting() { return _syntaxHighlighting; }
 
 private:
     bool          _apply_tag_try_link(Gtk::TextIter iter_end, int offset_cursor);
@@ -80,6 +81,13 @@ private:
     /// Replace the char between iter_start and iter_end with another one
     void          _special_char_replace(Glib::ustring special_char, Gtk::TextIter iter_start, Gtk::TextIter iter_end);
 
+    void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
+                               int x,
+                               int y,
+                               const Gtk::SelectionData& selection_data,
+                               guint info,
+                               guint time) override;
+
 #ifdef MD_AUTO_REPLACEMENT
     bool          _markdown_filter_active();
 #endif // MD_AUTO_REPLACEMENT
@@ -98,4 +106,5 @@ private:
     CtMainWin*   _pCtMainWin;
     CtColumnEdit _columnEdit;
     guint32      _todoRotateTime{0};
+    std::string  _syntaxHighlighting;
 };
